@@ -25,6 +25,10 @@ PythonSettingsWidget::PythonSettingsWidget(QWidget* parent, const QString& id) :
     setupUi(this);
 
     m_tabWidget = tabWidget;
+#ifdef HAVE_EMBEDDED_DOCUMENTATION
     m_tabDocumentation = tabDocumentation;
+#else
+    tabWidget->removeTab(2);
+#endif
     connect(tabWidget, &QTabWidget::currentChanged, this, &BackendSettingsWidget::tabChanged);
 }
